# Пример ручной калибровки бампера:

##  Калибровка заключается в определении среднего значения АЦП снятого с датчика находящегося над фоном и над линией.
##  При успешной калибровке, данные значения сохраняются для каждого датчика в энергонезависимой памяти модуля.
##  Далее, модуль определяет наличие линий под датчиками, сравнивая среднее значение АЦП с текущими показаниями АЦП своих датчиков.
##
##  При автоматической калибровке модуль сначала считывает показания АЦП с датчиков находящихся над линиями, а потом над фоном,
##  самостоятельно рассчитывает среднее значение АЦП для каждого датчика и сохраняет полученные данные в своей памяти.
##
##  При ручной калибровке Вы сами рассчитываете средние значения АЦП для каждого датчика и отправляете их модулю функцией setCalibrationManual().
##  Для самостоятельного рассчёта среднего значения АЦП, нужно знать значения АЦП для линии и фона. Узнать текущее значение АЦП любого датчика можно функцией getLineAnalog().
##
##  Если Вы желаете указать одно среднее значение АЦП для всех датчиков модуля, то обратитесь к функции setCalibrationManual() указав одно значение.
##  Если Вы желаете указать среднее значение АЦП для каждого датчика модуля, то обратитесь к функции setCalibrationManual() указав девять значений.
##
##  setCalibrationManual(АЦП для всех датчивов модуля)
##  setCalibrationManual(АЦП 1 датчика, АЦП 2 датчика, АЦП 3 датчика, АЦП 4 датчика, АЦП 5 датчика, АЦП 6 датчика, АЦП 7 датчика, АЦП 8 датчика, АЦП 9 датчика)

from pyiArduinoI2Cbumper import *                           #   Подключаем библиотеку для работы с бампером I2C-flash.
bum = pyiArduinoI2Cbumper(0x09)                             #   Объявляем объект bum для работы с функциями и методами библиотеки pyiArduinoI2Cbumper, указывая адрес модуля на шине I2C.

#  КАЛИБРУЕМ МОДУЛЬ:
#   Выполняем калибровку указав значение АЦП между фоном и линией для всех датчиков модуля.
f = bum.setCalibrationManual(700)

if f == True:
    print("Модуль успешно откалиброван!")
else:
    print("Ошибка калибровки модуля!"   )

#  ЗАДАЁМ ТИП ЛИНИИ ТРАССЫ:
# * Указываем тип линии трассы: BUM_LINE_BLACK - тёмная / BUM_LINE_WHITE - светлая / BUM_LINE_CHANGE - сменить тип линии.
f = bum.setLineType(BUM_LINE_BLACK)
if f:
    print("Тип линии трассы задан!"     )
else:
    print("Ошибка указания типа линии!" )
